@@ -4,7 +4,7 @@ def factorial(n):
 
 def double_factorial(n):
     if n == 0: return 1
-    else: return n * factorial(n - 2)
+    else: return n * double_factorial(n - 2)
 
 def subfactorial(n):
     return round(factorial(n) / 2.718)
